@@ -837,11 +837,10 @@ class TemplateParser(object):
         sys.stdout = exec_buffer
         temp_context = {}
         temp_context.update(self.context)
-        pass
         temp_context.update(*args, **kwargs)
         code = str(self)
         try: 
-            exec(code, temp_context) 
+            exec code in temp_context 
             sys.stdout = sys.__stdout__
             self.last_output = exec_buffer.getvalue()
             exec_buffer.close()
